eyeball
=======

.. image:: https://travis-ci.org/wuub/eyeball.png
   :target: https://travis-ci.org/wuub/eyeball

Python 2.7, Python 3.3 and PyPy compatible.

Code block manipulation with some help from ast module
Pre-alpha
